"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImportFromUrlControllerProcessAssetsStep = void 0;
var _types = require("../../../types");
var _ImportFromUrlController = require("../abstractions/ImportFromUrlController");
var _importPath = require("../../utils/helpers/importPath");
var _getBackOffSeconds = require("../../utils/helpers/getBackOffSeconds");
var _constants = require("../../constants");
var _getChildTasks = require("./getChildTasks");
class ImportFromUrlControllerProcessAssetsStep {
  async execute(params) {
    const {
      response,
      input,
      trigger,
      store,
      context
    } = params;
    const task = store.getTask();
    const step = input.steps[_ImportFromUrlController.IImportFromUrlControllerInputStep.PROCESS_ASSETS];
    if (!step?.triggered) {
      const files = input.files.filter(file => {
        return file.type === _types.CmsImportExportFileType.ASSETS;
      });
      if (files.length === 0) {
        const output = {
          error: {
            message: "No assets files found.",
            code: "NO_ASSETS_FILES"
          },
          files: [],
          aborted: [],
          done: [],
          failed: [],
          invalid: []
        };
        return response.done(output);
      }
      const inputFiles = [];
      for (const file of files) {
        const key = (0, _importPath.prependImportPath)(file.key);
        await trigger({
          name: `Import From Url - Process assets`,
          definition: _constants.IMPORT_FROM_URL_PROCESS_ASSETS_TASK,
          input: {
            file: {
              key,
              type: file.type
            },
            maxInsertErrors: input.maxInsertErrors,
            modelId: input.modelId
          }
        });
        inputFiles.push(key);
      }
      const output = {
        ...input,
        steps: {
          ...input.steps,
          [_ImportFromUrlController.IImportFromUrlControllerInputStep.PROCESS_ASSETS]: {
            ...step,
            triggered: true,
            files: inputFiles
          }
        }
      };
      return response.continue(output, {
        seconds: (0, _getBackOffSeconds.getBackOffSeconds)(task.iterations)
      });
    } else if (step.finished !== true) {
      const {
        failed,
        running,
        invalid,
        aborted,
        collection,
        done
      } = await (0, _getChildTasks.getChildTasks)({
        context,
        task,
        definition: _constants.IMPORT_FROM_URL_PROCESS_ASSETS_TASK
      });

      /**
       * If there are any running tasks, we should continue waiting.
       */
      if (running.length > 0) {
        return response.continue(input, {
          seconds: (0, _getBackOffSeconds.getBackOffSeconds)(task.iterations)
        });
      } else if (collection.length === 0) {
        return response.error({
          message: "No process assets tasks found. We are not continuing.",
          code: "NO_PROCESS_ASSETS_TASKS"
        });
      }
      const output = {
        ...input,
        steps: {
          ...input.steps,
          [_ImportFromUrlController.IImportFromUrlControllerInputStep.PROCESS_ASSETS]: {
            ...step,
            failed,
            invalid,
            aborted,
            done,
            finished: true
          }
        }
      };
      return response.continue(output);
    }
    return response.error({
      message: "Impossible to get to this point. Fatal error."
    });
  }
}
exports.ImportFromUrlControllerProcessAssetsStep = ImportFromUrlControllerProcessAssetsStep;

//# sourceMappingURL=ImportFromUrlControllerProcessAssetsStep.js.map