"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImportFromUrlProcessEntriesDecompress = void 0;
var _getFilePath = require("../../utils/helpers/getFilePath");
var _error = require("@webiny/error");
class ImportFromUrlProcessEntriesDecompress {
  constructor(params) {
    this.reader = params.reader;
    this.decompressor = params.decompressor;
  }
  async run(params) {
    const {
      response,
      input,
      isCloseToTimeout,
      isAborted
    } = params;
    const result = structuredClone(input);
    const files = (await this.reader.read(result.file.key)).sort((a, b) => {
      return a.uncompressedSize - b.uncompressedSize;
    });
    if (files.length === 0) {
      return response.error({
        message: `No files found in the compressed archive.`,
        code: "NO_FILES_FOUND"
      });
    }
    const extractPath = (0, _getFilePath.getFilePath)(result.file.key);
    while (true) {
      const next = result.decompress?.next || 0;
      const source = files.at(next);
      if (!source) {
        return response.continue({
          ...result,
          decompress: {
            ...result.decompress,
            done: true
          }
        });
      } else if (isAborted()) {
        return response.aborted();
      } else if (isCloseToTimeout() || result.decompress?.done) {
        return response.continue({
          ...result
        });
      }
      try {
        const target = `extracted/${extractPath.path}/${source.path}`;
        const file = await this.decompressor.extract({
          source,
          target
        });
        if (!file.Key) {
          throw new _error.WebinyError({
            message: `Could not upload the file "${source.path}".`,
            code: "FILE_NOT_UPLOAD",
            data: {
              source: source.path,
              target
            }
          });
        }
        result.decompress = {
          ...result.decompress,
          next: next + 1,
          files: [...(result.decompress?.files || []), file.Key]
        };
      } catch (ex) {
        return response.error(ex);
      }
    }
  }
}
exports.ImportFromUrlProcessEntriesDecompress = ImportFromUrlProcessEntriesDecompress;

//# sourceMappingURL=ImportFromUrlProcessEntriesDecompress.js.map