"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDecompressor = exports.Decompressor = void 0;
var _stream = require("stream");
class Decompressor {
  constructor(params) {
    this.createUploadFactory = params.createUploadFactory;
  }
  /**
   * Should not be used with large files (> 10/20MB)
   */
  async read(files, target) {
    const file = files.find(f => f.path === target);
    if (!file) {
      throw new Error(`File "${target}" not found in the compressed file.`);
    }
    const buffer = await file.buffer();
    return buffer.toString();
  }
  async extract(params) {
    const {
      source,
      target
    } = params;
    const factory = this.createUploadFactory(target);
    const multipartUpload = await factory.start();
    const promises = [];
    const localStream = new _stream.PassThrough({
      autoDestroy: true
    }).on("error", err => {
      console.log("Decompressor Local Stream Error", err);
      throw err;
    }).on("data", data => {
      const p = multipartUpload.add(data);
      promises.push(p);
    });
    let stream;
    try {
      stream = source.stream();
    } catch (ex) {
      console.error(`Failed to create stream for "${source.path}".`, ex);
      throw ex;
    }
    return new Promise((resolve, reject) => {
      let alreadyDone = false;
      let alreadyError = false;
      const done = async () => {
        if (alreadyDone) {
          return;
        }
        alreadyDone = true;
        try {
          await Promise.all(promises);
          const result = await multipartUpload.complete();
          resolve(result.result);
        } catch (ex) {
          console.error("Failed to upload file.", ex);
          multipartUpload.abort();
          reject(ex);
        } finally {
          stream.destroy();
        }
      };
      const error = async err => {
        if (alreadyError) {
          return;
        }
        alreadyError = true;
        try {
          await multipartUpload.abort();
          reject(err);
        } catch (ex) {
          reject(ex);
        } finally {
          stream.destroy();
        }
      };
      stream.pipe(localStream).on("finish", () => {
        done();
      }).on("error", err => {
        error(err);
      });
    });
  }
}
exports.Decompressor = Decompressor;
const createDecompressor = params => {
  return new Decompressor(params);
};
exports.createDecompressor = createDecompressor;

//# sourceMappingURL=Decompressor.js.map