"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeleteFiles = exports.DeleteFiles = void 0;
var _s3Client = require("../helpers/s3Client");
var _fileFetcher = require("../fileFetcher");
var _getBucket = require("../helpers/getBucket");
class DeleteFiles {
  constructor(params) {
    this.fileFetcher = params.fileFetcher;
  }
  async execute(input) {
    if (!input) {
      return;
    }
    const files = (Array.isArray(input) ? input : [input]).filter(file => {
      return !!file;
    });
    for (const file of files) {
      const exists = await this.fileFetcher.exists(file);
      if (!exists) {
        continue;
      }
      try {
        const result = await this.fileFetcher.delete(file);
        if (!result.$metadata) {
          continue;
        }
        if (result.$metadata.httpStatusCode !== 200) {
          console.log(`Failed to delete file "${file}".`);
        }
      } catch (ex) {
        console.log(`Failed to delete file "${file}".`, ex);
      }
    }
  }
}
exports.DeleteFiles = DeleteFiles;
const createDeleteFiles = () => {
  const client = (0, _s3Client.createS3Client)();
  const bucket = (0, _getBucket.getBucket)();
  return new DeleteFiles({
    fileFetcher: new _fileFetcher.FileFetcher({
      client,
      bucket
    })
  });
};
exports.createDeleteFiles = createDeleteFiles;

//# sourceMappingURL=DeleteFiles.js.map