"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntryAssets = void 0;
var _matchKeyOrAlias = require("../helpers/matchKeyOrAlias");
const fileTypes = ["file"];
class EntryAssets {
  constructor(params) {
    this.traverser = params.traverser;
    this.uniqueResolver = params.uniqueResolver;
  }
  async assignAssets(input) {
    const entries = Array.isArray(input) ? input : [input];
    if (entries.length === 0) {
      return [];
    }
    const assets = [];
    for (const entry of entries) {
      if (!entry?.values) {
        continue;
      }
      await this.traverser.traverse(entry.values, ({
        field,
        value
      }) => {
        if (!value || fileTypes.includes(field.type) === false) {
          return;
        }
        assets.push(...this.assignAssetsToItems(value));
      });
    }
    return assets;
  }
  parseAssetSrc(input) {
    if (!input || typeof input !== "string" || !input.trim()) {
      return null;
    }
    const result = (0, _matchKeyOrAlias.matchKeyOrAlias)(input);
    if (!result) {
      return null;
    }
    return {
      ...result,
      url: input
    };
  }
  assignAssetsToItems(input) {
    const assets = {};
    if (!input) {
      return [];
    }
    const inputArray = Array.isArray(input) ? input : [input];
    for (const src of inputArray) {
      const asset = this.parseAssetSrc(src);
      if (!asset) {
        continue;
      } else if (assets[asset.url]) {
        continue;
      }
      assets[asset.url] = asset;
    }
    return this.uniqueResolver.resolve(Object.values(assets), "url");
  }
}
exports.EntryAssets = EntryAssets;

//# sourceMappingURL=EntryAssets.js.map