"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UrlSigner = void 0;
var _clientS = require("@webiny/aws-sdk/client-s3");
const DEFAULT_TIMEOUT = 3600; // 1 hour

class UrlSigner {
  constructor(params) {
    this.client = params.client;
    this.bucket = params.bucket;
  }
  async get(params) {
    return this.sign(params, _clientS.GetObjectCommand);
  }
  async head(params) {
    return this.sign(params, _clientS.HeadObjectCommand);
  }
  async sign(params, command) {
    const expiresIn = params.timeout || DEFAULT_TIMEOUT;
    const expiresOn = new Date(new Date().getTime() + expiresIn * 1000);
    const url = await (0, _clientS.getSignedUrl)(this.client, new command({
      Bucket: this.bucket,
      Key: params.key
    }), {
      expiresIn
    });
    return {
      url,
      bucket: this.bucket,
      key: params.key,
      expiresOn
    };
  }
}
exports.UrlSigner = UrlSigner;

//# sourceMappingURL=UrlSigner.js.map